@@ -4,11 +4,17 @@ use Moose;
 use MooseX::App::Command;
 extends qw(Test01);
 
-has 'email' => (
+has 'param_a' => (
     isa         => 'Str',
     is          => 'rw',
 );
 
+option 'param_b' => (
+    isa         => 'Str',
+    is          => 'rw',
+    required    => 1,
+);
+
 sub run { 
     print "RUN COMMAND-B";
 }
@@ -19,6 +25,10 @@ sub run {
 
 Test01::CommandB - Test class command B for test 01
 
+=head1 SYNOPSIS
+
+use with care
+
 =head1 DESCRIPTION
 
 Some description of B<command B>
